@@ -5,10 +5,43 @@ import (
 	"net/url"
 	"sync"
 
+	"github.com/hahwul/dalfox/v2/internal/optimization"
+	"github.com/hahwul/dalfox/v2/internal/payload"
+	"github.com/hahwul/dalfox/v2/internal/printing"
 	"github.com/hahwul/dalfox/v2/pkg/model"
-	"github.com/hahwul/dalfox/v2/pkg/optimization"
 )
 
+// RunBAVAnalysis runs the BAV analysis.
+func RunBAVAnalysis(target string, options model.Options, rl *rateLimiter, bav *string) {
+	var bavWaitGroup sync.WaitGroup
+	bavTask := 5
+	bavWaitGroup.Add(bavTask)
+	go func() {
+		defer bavWaitGroup.Done()
+		ESIIAnalysis(target, options, rl)
+	}()
+	go func() {
+		defer bavWaitGroup.Done()
+		SqliAnalysis(target, options, rl)
+	}()
+	go func() {
+		defer bavWaitGroup.Done()
+		SSTIAnalysis(target, options, rl)
+	}()
+	go func() {
+		defer bavWaitGroup.Done()
+		CRLFAnalysis(target, options, rl)
+	}()
+	go func() {
+		defer bavWaitGroup.Done()
+		OpenRedirectorAnalysis(target, options, rl)
+	}()
+
+	bavWaitGroup.Wait()
+	*bav = " > BAV(o)"
+	printing.DalLog("SYSTEM", "["+*bav+"] BAV analysis completed", options)
+}
+
 // SSTIAnalysis is basic check for SSTI
 func SSTIAnalysis(target string, options model.Options, rl *rateLimiter) {
 	// Build-in Grepping payload :: SSTI
@@ -33,7 +66,7 @@ func SSTIAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 	for bpk := range bpd {
 		if optimization.CheckInspectionParam(options, bpk) {
-			for _, ssti := range getSSTIPayload() {
+			for _, ssti := range payload.GetSSTIPayload() {
 				turl, _ := optimization.MakeRequestQuery(target, bpk, ssti, "toGrepping", "ToAppend", "Nan", options)
 				reqs <- turl
 			}
@@ -43,7 +76,7 @@ func SSTIAnalysis(target string, options model.Options, rl *rateLimiter) {
 	wg.Wait()
 }
 
-//CRLFAnalysis is basic check for CRLF Injection
+// CRLFAnalysis is basic check for CRLF Injection
 func CRLFAnalysis(target string, options model.Options, rl *rateLimiter) {
 	bpu, _ := url.Parse(target)
 	bpd := bpu.Query()
@@ -64,7 +97,7 @@ func CRLFAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 	for bpk := range bpd {
 		if optimization.CheckInspectionParam(options, bpk) {
-			for _, crlfpayload := range getCRLFPayload() {
+			for _, crlfpayload := range payload.GetCRLFPayload() {
 				turl, _ := optimization.MakeRequestQuery(target, bpk, crlfpayload, "toGrepping", "ToAppend", "NaN", options)
 				reqs <- turl
 			}
@@ -75,7 +108,7 @@ func CRLFAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 }
 
-//ESIIAnalysis is basic check for CRLF Injection
+// ESIIAnalysis is basic check for CRLF Injection
 func ESIIAnalysis(target string, options model.Options, rl *rateLimiter) {
 	bpu, _ := url.Parse(target)
 	bpd := bpu.Query()
@@ -96,7 +129,7 @@ func ESIIAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 	for bpk := range bpd {
 		if optimization.CheckInspectionParam(options, bpk) {
-			for _, crlfpayload := range getESIIPayload() {
+			for _, crlfpayload := range payload.GetESIIPayload() {
 				turl, _ := optimization.MakeRequestQuery(target, bpk, crlfpayload, "toGrepping", "ToAppend", "NaN", options)
 				reqs <- turl
 			}
@@ -107,7 +140,7 @@ func ESIIAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 }
 
-//SqliAnalysis is basic check for SQL Injection
+// SqliAnalysis is basic check for SQL Injection
 func SqliAnalysis(target string, options model.Options, rl *rateLimiter) {
 	// sqli payload
 
@@ -130,7 +163,7 @@ func SqliAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 	for bpk := range bpd {
 		if optimization.CheckInspectionParam(options, bpk) {
-			for _, sqlipayload := range getSQLIPayload() {
+			for _, sqlipayload := range payload.GetSQLIPayload() {
 				turl, _ := optimization.MakeRequestQuery(target, bpk, sqlipayload, "toGrepping", "ToAppend", "NaN", options)
 				reqs <- turl
 			}
@@ -141,7 +174,7 @@ func SqliAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 }
 
-//OpenRedirectorAnalysis is basic check for open redirectors
+// OpenRedirectorAnalysis is basic check for open redirectors
 func OpenRedirectorAnalysis(target string, options model.Options, rl *rateLimiter) {
 
 	// openredirect payload
@@ -164,7 +197,7 @@ func OpenRedirectorAnalysis(target string, options model.Options, rl *rateLimite
 
 	for bpk := range bpd {
 		if optimization.CheckInspectionParam(options, bpk) {
-			for _, openRedirectPayload := range getOpenRedirectPayload() {
+			for _, openRedirectPayload := range payload.GetOpenRedirectPayload() {
 				turl, _ := optimization.MakeRequestQuery(target, bpk, openRedirectPayload, "toOpenRedirecting", "toReplace", "NaN", options)
 				reqs <- turl
 			}
